Concurrent Version System (CVS) and Subversion (SVN) provide a method
for application developers to control different versions of their
code.

Occasionally, the developer's version or user information can
be stored incorrectly within the code and may be visible to the end
user (either in the HTML or code comments). As one of the initial
steps in information gathering, cyber-criminals will spider a website
and using automated methods attempt to discover any CVS/SVN
information that may be present in the page.

This will aid them in
developing a better understanding of the deployed application
(potentially through the disclosure of version information), or it may
assist in further information gathering or social engineering attacks.
Using the same automated methods, the tool was able to detect CVS or
SVN details stored within the affected page.